=====================
``collectors`` module
=====================

.. automodule:: whoosh.collectors


Base classes
============

.. autoclass:: Collector
    :members:

.. autoclass:: ScoredCollector
    :members:

.. autoclass:: WrappingCollector
    :members:


Basic collectors
================

.. autoclass:: TopCollector

.. autoclass:: UnlimitedCollector

.. autoclass:: SortingCollector


Wrappers
========

.. autoclass:: FilterCollector

.. autoclass:: FacetCollector

.. autoclass:: CollapseCollector

.. autoclass:: TimeLimitCollector

.. autoclass:: TermsCollector





